ColumnInfo class

Allows customization of the column associated with this field.

Constructors

ColumnInfo({String? name})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
The custom name of the column.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited