Fts4 class

Marks an Entity annotated class as an FTS4 entity. This class will have a mapping SQLite FTS4 table in the database.

Constructors

Fts4({String tokenizer = FtsTokenizer.simple, List<String> tokenizerArgs = const []})
Creates an Fts4 constant which can be used to mark an Entity annotated class as an FTS4 entity.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenizer → String
The tokenizer to be used in the FTS table. The default value is FtsTokenizer.simple. Tokenizer arguments can be defined with tokenizerArgs.
final
tokenizerArgs → List<String>
Optional arguments to configure the defined tokenizer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited